Queue

Struct Queue 

pub struct Queue(/* private fields */);
The Queue connects a host program to a single device. Programs submit tasks to a device via the Queue and may monitor the Queue for completion. A program initiates the task by submitting a kernel.

Implementations

Source

impl Queue

pub fn new() -> Self

Construct a Queue based on the device returned from the default selector.

pub unsafe fn alloc_uninit_host<T>( &self, len: usize, ) -> Buffer<T, UsmAllocator<'_, HostAllocator>>

Allocates memory and creates a host-side Buffer that can store an array of T. Safety: the buffer contents are uninitialized.

pub unsafe fn alloc_uninit_shared<T>( &self, len: usize, ) -> Buffer<T, UsmAllocator<'_, SharedAllocator>>

Allocates memory and creates a shared Buffer that can store an array of T. Safety: the buffer contents are uninitialized.