pub struct Queue(/* private fields */);Expand description
The Queue connects a host program to a single device. Programs submit tasks to a device via the
Queue and may monitor the Queue for completion. A program initiates the task by submitting
a kernel.
Implementations
Sourceimpl Queue
impl Queue
Sourcepub unsafe fn alloc_uninit_host<T>(
&self,
len: usize,
) -> Buffer<T, UsmAllocator<'_, HostAllocator>>
pub unsafe fn alloc_uninit_host<T>( &self, len: usize, ) -> Buffer<T, UsmAllocator<'_, HostAllocator>>
Allocates memory and creates a host-side Buffer that can store an array of T.
Safety: the buffer contents are uninitialized.
Allocates memory and creates a shared Buffer that can store an array of T.
Safety: the buffer contents are uninitialized.